@@ -7,7 +7,11 @@ from typing import ByteString, Tuple
 from tqdm import tqdm
 
 _CHUNK_SIZE = 0x100000
-_HL_PAT = re.compile(r'([0-9a-fA-F]+) \*(.+)')
+_HL_PAT = re.compile(r'([0-9a-fA-F]+) (?:\*| )?(.+)')
+
+
+class IsDirectory(OSError):
+    """Raised by function `calc_hash`."""
 
 
 class ParseHashLineError(ValueError):
@@ -37,11 +41,11 @@ def calc_hash(
 
     A tqdm progressbar is also available.
     """
+    if os.path.isdir(path):
+        raise IsDirectory('"{}" is a directory'.format(path))
     ctx = ctx_proto.copy()
     file_size = os.path.getsize(path)
-    leave = tqdm_args.pop('leave', False)
-    ascii = tqdm_args.pop('ascii', True)
-    bar = tqdm(total=file_size, leave=leave, ascii=ascii, **tqdm_args)
+    bar = tqdm(total=file_size, **tqdm_args)
     with bar as bar, open(path, 'rb') as f:
         while True:
             chunk = f.read(chunk_size)
@@ -72,21 +76,29 @@ def phl(hash_line: str) -> Tuple[bytes, str]:
     return bytes.fromhex(hash_value), path
 
 
-def ghl(ctx_proto, path, **tqdm_args):
+def ghl(ctx_proto, path, *, inplace=False, **tqdm_args):
     """Generate hash line.
 
     Require path; return hash line.
     """
     hash_value = calc_hash(ctx_proto, path, **tqdm_args)
+    if inplace:
+        path = os.path.basename(path)
     return fhl(hash_value, path)
 
 
-def chl(ctx_proto, hash_line, **tqdm_args):
+def chl(ctx_proto, hash_line, *, inplace=False, **tqdm_args):
     """Check hash line.
 
     Require hash line; return path.
     """
     hash_value, path = phl(hash_line)
+    try:
+        hash_path = os.fspath(inplace)
+    except TypeError:
+        pass
+    else:
+        path = os.path.join(os.path.dirname(hash_path), path)
     curr_hash_value = calc_hash(ctx_proto, path, **tqdm_args)
     if not compare_digest(hash_value, curr_hash_value):
         raise CheckHashLineError(hash_line, hash_value, path, curr_hash_value)
