@@ -1,26 +1,40 @@
 import os
 import sys
+from functools import partial, wraps
 from glob import iglob
 
 import click
 
+from . import __version__
 from ._core import CheckHashLineError, chl, ghl
 
 
-class MissingFile(FileNotFoundError):
-    """For the filename listed in checksum file but the file not exists."""
-
-
 class GetHash(object):
     """Provide script interfaces."""
 
     def __init__(self, ctx, *, suffix='.sha', **kwargs):
         self.ctx = ctx
         self.suffix = suffix
+
+        self.inplace = kwargs.pop('inplace', False)
+        self.no_file = kwargs.pop('no_file', False)
+        self.no_glob = kwargs.pop('no_glob', False)
         self.file = kwargs.pop('file', sys.stdout)
         self.errfile = kwargs.pop('errfile', sys.stderr)
-        self.no_glob = kwargs.pop('no_glob', False)
-        self.tqdm_args = {'file': self.file, **kwargs}
+
+        # Prepare arguments passed to tqdm.
+        leave = kwargs.pop('leave', False)
+        ascii = kwargs.pop('ascii', True)
+        self.tqdm_args = {
+            'file': self.file,
+            'leave': leave,
+            'ascii': ascii,
+            **kwargs
+        }
+
+        # Bind ghl/chl functions to current context.
+        self.ghlc = partial(ghl, self.ctx, **self.tqdm_args)
+        self.chlc = partial(chl, self.ctx, **self.tqdm_args)
 
     def echo(self, msg, **kwargs):
         click.echo(msg, file=self.file, **kwargs)
@@ -46,10 +60,11 @@ class GetHash(object):
     def generate_hash(self, patterns):
         for path in self.glob(patterns):
             try:
-                hash_line = ghl(self.ctx, path, **self.tqdm_args)
+                hash_line = self.ghlc(path, inplace=self.inplace)
                 hash_path = path + self.suffix
-                with open(hash_path, 'w', encoding='utf-8') as f:
-                    f.write(hash_line)
+                if not self.no_file:
+                    with open(hash_path, 'w', encoding='utf-8') as f:
+                        f.write(hash_line)
             except Exception as e:
                 self.echo_error(path, e)
             else:
@@ -57,7 +72,7 @@ class GetHash(object):
 
     def _check_hash(self, hash_line, hash_path):
         try:
-            path = chl(self.ctx, hash_line, **self.tqdm_args)
+            path = self.chlc(hash_line, inplace=hash_path)
         except CheckHashLineError as e:
             self.secho('[FAILURE] {}'.format(e.path), fg='red')
         except Exception as e:
@@ -77,23 +92,17 @@ class GetHash(object):
                 self.echo_error(hash_path, e)
 
 
-def script_main(command, ctx, suffix, check, files, **options):
-    # When no argument, print help.
-    if not files:
-        sys.argv.append('--help')
-        command()
-
-    # Resolve command-line options.
-
+def script_main(ctx, suffix, check, files, **options):
+    # Build GetHash context.
     no_stdout = options.pop('no_stdout', False)
-    file = open(os.devnull, 'w') if no_stdout else sys.stdout
-
     no_stderr = options.pop('no_stderr', False)
+    file = open(os.devnull, 'w') if no_stdout else sys.stdout
     errfile = open(os.devnull, 'w') if no_stderr else sys.stderr
-
-    no_glob = options.pop('no_glob', False)
-
-    args = {'file': file, 'errfile': errfile, 'no_glob': no_glob}
+    args = {
+        'file': file,
+        'errfile': errfile,
+        **options
+    }
     gh = GetHash(ctx, suffix=suffix, **args)
 
     if check:
@@ -104,17 +113,22 @@ def script_main(command, ctx, suffix, check, files, **options):
 
 def gethashcli(name):
     def decorator(func):
-        @click.command()
+        @click.command(no_args_is_help=True)
         @click.option('-c', '--check', is_flag=True,
                       help='Read {} from FILES and check them.'.format(name))
+        @click.option('-i', '--inplace', is_flag=True,
+                      help='Use basename in checksum files.')
+        @click.option('--no-file', is_flag=True,
+                      help='Do not output checksum files.')
+        @click.option('--no-glob', is_flag=True,
+                      help='Do not resolve glob patterns.')
         @click.option('--no-stdout', is_flag=True,
                       help='Do not output to stdout.')
         @click.option('--no-stderr', is_flag=True,
                       help='Do not output to stderr.')
-        @click.option('--no-glob', is_flag=True,
-                      help='Do not resolve glob patterns.')
-        @click.version_option()
+        @click.version_option(__version__)
         @click.argument('files', nargs=-1)
+        @wraps(func)
         def wrapper(*args, **kwargs):
             return func(*args, **kwargs)
         return wrapper
